@@ -67,15 +67,31 @@ public:
 
     int screen_w;
     int screen_h;
+
     int square_w[NB_SIZE];
     int square_h[NB_SIZE];
     int map_w[NB_SIZE];
     int map_h[NB_SIZE];
     int info_w[NB_SIZE];
     int info_h[NB_SIZE];
+
+    int offset_map_x[NB_SIZE];
+    int offset_map_y[NB_SIZE];
+    int offset_name_x[NB_SIZE];
+    int offset_name_y[NB_SIZE];
+    int offset_score_x[NB_SIZE];
+    int offset_score_y[NB_SIZE];
+    int offset_target_x[NB_SIZE];
+    int offset_target_y[NB_SIZE];
+    int offset_preview_x[NB_SIZE];
+    int offset_preview_y[NB_SIZE];
+    int offset_misc_x[NB_SIZE];
+    int offset_misc_y[NB_SIZE];
+   
     int nb_map;
 
     CL_Font *font_menu;
+    CL_Font *font_info[NB_SIZE];
  
     CL_SoundBuffer *sound_game_start;
     CL_SoundBuffer *sound_menu_move;
@@ -105,7 +121,59 @@ protected:
     static char *const ID_PROPERTY_SCREEN_W="property/screen_w";
     static char *const ID_PROPERTY_SCREEN_H="property/screen_h";
 
+    static char *const ID_PROPERTY_OFFSET_MAP_X_BIG=
+                         "property/offset_map_x_big";
+    static char *const ID_PROPERTY_OFFSET_MAP_Y_BIG=
+                         "property/offset_map_y_big";
+    static char *const ID_PROPERTY_OFFSET_NAME_X_BIG=
+                         "property/offset_name_x_big";
+    static char *const ID_PROPERTY_OFFSET_NAME_Y_BIG=
+                         "property/offset_name_y_big";
+    static char *const ID_PROPERTY_OFFSET_SCORE_X_BIG=
+                         "property/offset_score_x_big";
+    static char *const ID_PROPERTY_OFFSET_SCORE_Y_BIG=
+                         "property/offset_score_y_big";
+    static char *const ID_PROPERTY_OFFSET_TARGET_X_BIG=
+                         "property/offset_target_x_big";
+    static char *const ID_PROPERTY_OFFSET_TARGET_Y_BIG=
+                         "property/offset_target_y_big";
+    static char *const ID_PROPERTY_OFFSET_PREVIEW_X_BIG=
+                         "property/offset_preview_x_big";
+    static char *const ID_PROPERTY_OFFSET_PREVIEW_Y_BIG=
+                         "property/offset_preview_y_big";
+    static char *const ID_PROPERTY_OFFSET_MISC_X_BIG=
+                         "property/offset_misc_x_big";
+    static char *const ID_PROPERTY_OFFSET_MISC_Y_BIG=
+                         "property/offset_misc_y_big";
+
+    static char *const ID_PROPERTY_OFFSET_MAP_X_SMALL=
+                         "property/offset_map_x_small";
+    static char *const ID_PROPERTY_OFFSET_MAP_Y_SMALL=
+                         "property/offset_map_y_small";
+    static char *const ID_PROPERTY_OFFSET_NAME_X_SMALL=
+                         "property/offset_name_x_small";
+    static char *const ID_PROPERTY_OFFSET_NAME_Y_SMALL=
+                         "property/offset_name_y_small";
+    static char *const ID_PROPERTY_OFFSET_SCORE_X_SMALL=
+                         "property/offset_score_x_small";
+    static char *const ID_PROPERTY_OFFSET_SCORE_Y_SMALL=
+                         "property/offset_score_y_small";
+    static char *const ID_PROPERTY_OFFSET_TARGET_X_SMALL=
+                         "property/offset_target_x_small";
+    static char *const ID_PROPERTY_OFFSET_TARGET_Y_SMALL=
+                         "property/offset_target_y_small";
+    static char *const ID_PROPERTY_OFFSET_PREVIEW_X_SMALL=
+                         "property/offset_preview_x_small";
+    static char *const ID_PROPERTY_OFFSET_PREVIEW_Y_SMALL=
+                         "property/offset_preview_y_small";
+    static char *const ID_PROPERTY_OFFSET_MISC_X_SMALL=
+                         "property/offset_misc_x_small";
+    static char *const ID_PROPERTY_OFFSET_MISC_Y_SMALL=
+                         "property/offset_misc_y_small";
+
     static char *const ID_FONT_MENU="font/menu";
+    static char *const ID_FONT_INFO_BIG="font/info_big";
+    static char *const ID_FONT_INFO_SMALL="font/info_small";
 
     static char *const ID_SOUND_GAME_START="sound/game_start";
     static char *const ID_SOUND_MENU_MOVE="sound/menu_move";
