@@ -130,6 +130,7 @@ void U61_Map::begin()
     clear();
  
     block.reset();
+    next_block.reset();
     block_requested=false;
     matching=false;
     speed_counter=0;
@@ -975,6 +976,9 @@ void U61_Map::new_block(int shape)
 
     next_block.shape(shape);
 
+    next_block.corner();
+    block.center();
+
     //cout<<"new block given\n";
 }
 
