@@ -77,13 +77,23 @@ public:
     int get_background();
     void set_square_color(int x,int y,int color);
     int get_square_color(int x,int y);
+
     void set_score(int s);
     int get_score();
+    int get_best_score();
+    void add_score(int s);
+    int get_time();
+    int get_nb_games();
+    int get_match_count();
+    void set_global(int i,int glob);
+    int get_global(int i);
 
     void draw(int x,int y, 
               int size=U61_Data::SIZE_BIG,
               bool prev=false);
 
+    void mute();
+
     bool is_active();
     void set_active(int time);
     void set_inactive();
@@ -91,17 +101,24 @@ public:
     void set_prevision_state(bool state);
     bool get_prevision_state();
 
+    void set_preview_state(bool state);
+    bool get_preview_state();
+
     void set_speed(int s);
     int get_speed();
 
     void set_accel(int a);
     int get_accel();
 
+    U61_Block get_next_block();
+
     static const int WIDTH=10;
     static const int HEIGHT=25;
+    static const int NB_GLOBAL=1000;
     static const int SPEED_SCALE=1000;
     static const int ACCEL_SCALE=100000;
-    static const int MAX_USER_SPEED=10;
+    static const int TIME_CALLBACK_DELAY=10;
+    static const int MAX_USER_SPEED=20;
     static const int MAX_USER_ACCEL=10;
     static const int MAX_SYSTEM_SPEED=50;
     static const int MAX_SYSTEM_ACCEL=15;
@@ -111,12 +128,17 @@ protected:
 
     U61_Square squares[WIDTH][HEIGHT];
     U61_Block block;
+    U61_Block next_block;
     U61_Block block_prevision;
     list<U61_Event> auto_events;
+    int global_val[NB_GLOBAL];
+
     int background;
     bool active;
+    bool silent;
     int map_time;
     bool block_requested;
+    bool matching;
     int speed_counter;
     int accel_counter;
     int speed;
@@ -124,8 +146,11 @@ protected:
     int base_speed;
     int base_accel;
     int score;
+    int best_score;
     int games;
+    int match_count;
     bool prevision_state;
+    bool preview_state;
 
     void compute_next();
     void update_speed();
@@ -144,11 +169,12 @@ protected:
     bool is_block_active();
     bool is_block_ok(U61_Block *test);
   
-    void new_block();
+    void new_block(int shape);
     void stabilize_block();
     void loose();
 
     void match_pattern();
+    void time_callback();
 
     void check_speed();
     void check_accel();
