@@ -380,11 +380,14 @@ void U61_Script::block_land(U61_Map *m,U61_Block *b)
  * and deletes the approprated blocks
  * this function should also update the score
  */
-void U61_Script::map_match_pattern(U61_Map *m)
+bool U61_Script::map_match_pattern(U61_Map *m)
 {
     CL_LuaObject func;
+    CL_LuaObject obj;
+    CL_LuaObject arg1;
     char command[U61_STRING_SIZE];
     char arguments[U61_STRING_SIZE];
+    float result=0.;
 
     secure_pointers();
     current_map=m;
@@ -394,10 +397,65 @@ void U61_Script::map_match_pattern(U61_Map *m)
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
 
-    sprintf(arguments,"()");
+    sprintf(arguments,"(%d)",m->get_match_count());
     strcpy(command,LUA_MAP_MATCH_PATTERN);
     strcat(command,arguments);
+    //CL_Lua::dostring(command);
+
+    //arg1=m->get_match_count();
+    //func=CL_Lua::getglobal(LUA_MAP_MATCH_PATTERN);
+    //CL_Lua::pushobject(arg1);
+    //CL_Lua::callfunction(func);
+
+    //obj=CL_Lua::getresult(0);
+    lua_pushnumber(m->get_match_count());
+    lua_callfunction(lua_getglobal(LUA_MAP_MATCH_PATTERN));
+    result=lua_getnumber(lua_getresult(1));
+
+//    if (obj.isNumber())
+//    {
+//        cout<<"is a number";
+//        result=obj;
+//    }    
+//    else
+//    {
+//        cout<<"not a number";
+//    }
+//    cout<<"c:"<<result<<"\n";
+
+    return (result>0.);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * function called on a regular time basis
+ * it can update or modify anything in the map or the block
+ * usefull to implement some curses, and/or update the score
+ * it is called about 10 times/sec, and the rate does not increase
+ * with the global speed of the game
+ */
+void U61_Script::map_time_callback(U61_Map *m,U61_Block *b)
+{
+    CL_LuaObject func;
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
+
+    secure_pointers();
+    current_map=m;
+    current_block=b;
+    map_read=true;
+    map_write=true;
+    block_read=true;
+    block_write=true;
+
+    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+    //lua_callfunction(func);
+
+    sprintf(arguments,"()");
+    strcpy(command,LUA_MAP_TIME_CALLBACK);
+    strcat(command,arguments);
     CL_Lua::dostring(command);
+
 }
 
 /*--------------------------------------------------------------------------*/
@@ -718,6 +776,40 @@ static void map_set_square_color()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it returns the time associated to a map
+ */
+static void map_get_time()
+{
+    CL_LuaValue *score;
+
+    if (current_map!=NULL && map_read)
+    {
+        score=new CL_LuaValue(current_map->get_time());
+        score->push();
+        delete score;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it returns the number of games played on a map
+ */
+static void map_get_nb_games()
+{
+    CL_LuaValue *score;
+
+    if (current_map!=NULL && map_read)
+    {
+        score=new CL_LuaValue(current_map->get_nb_games());
+        score->push();
+        delete score;
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
@@ -738,7 +830,7 @@ static void map_get_score()
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
- * it sets the value of the socre associated to a map
+ * it sets the value of the score associated to a map
  */
 static void map_set_score()
 {
@@ -752,6 +844,128 @@ static void map_set_score()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it adds the value to the score associated to a map
+ */
+static void map_add_score()
+{
+    int score;
+
+    if (current_map!=NULL && map_write)
+    {
+        score=CL_Lua::getparam(1);
+
+        current_map->add_score(score);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it allows the user scripts to get global values associated to a map
+ */
+static void map_get_global()
+{
+    CL_LuaValue *glob;
+    int i;
+
+    if (current_map!=NULL && map_read)
+    {
+        i=CL_Lua::getparam(1);
+        glob=new CL_LuaValue(current_map->get_global(i));
+        glob->push();
+        delete glob;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it allows the user scripts to set global values associated to a map
+ */
+static void map_set_global()
+{
+    int i,glob;
+
+    if (current_map!=NULL && map_write)
+    {
+        i=CL_Lua::getparam(1);
+        glob=CL_Lua::getparam(2);
+
+        current_map->set_global(i,glob);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it returns the prevision state, ie if the prevision is to be seen
+ */
+static void map_get_prevision_state()
+{
+    CL_LuaValue *state;
+
+    if (current_map!=NULL && map_read)
+    {
+        state=new CL_LuaValue(current_map->get_prevision_state() ? 1 : 0);
+        state->push();
+        delete state;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it sets the prevision state, ie if the prevision is to be seen
+ */
+static void map_set_prevision_state()
+{
+    int state;
+
+    if (current_map!=NULL && map_write)
+    {
+        state=CL_Lua::getparam(1);
+
+        current_map->set_prevision_state(state);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it returns the preview state, ie if the preview is to be seen
+ */
+static void map_get_preview_state()
+{
+    CL_LuaValue *state;
+
+    if (current_map!=NULL && map_read)
+    {
+        state=new CL_LuaValue(current_map->get_preview_state() ? 1 : 0);
+        state->push();
+        delete state;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it sets the preview state, ie if the preview is to be seen
+ */
+static void map_set_preview_state()
+{
+    int state;
+
+    if (current_map!=NULL && map_write)
+    {
+        state=CL_Lua::getparam(1);
+
+        current_map->set_preview_state(state);
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * registers all C functions that can be used from Lua
@@ -776,8 +990,17 @@ void U61_Script::record_all()
     CL_Lua::record(C_MAP_GET_HEIGHT,map_get_height);
     CL_Lua::record(C_MAP_GET_SQUARE_COLOR,map_get_square_color);
     CL_Lua::record(C_MAP_SET_SQUARE_COLOR,map_set_square_color);
+    CL_Lua::record(C_MAP_GET_TIME,map_get_time);
+    CL_Lua::record(C_MAP_GET_NB_GAMES,map_get_nb_games);
     CL_Lua::record(C_MAP_GET_SCORE,map_get_score);
     CL_Lua::record(C_MAP_SET_SCORE,map_set_score);
+    CL_Lua::record(C_MAP_ADD_SCORE,map_add_score);
+    CL_Lua::record(C_MAP_GET_GLOBAL,map_get_global);
+    CL_Lua::record(C_MAP_SET_GLOBAL,map_set_global);
+    CL_Lua::record(C_MAP_GET_PREVISION_STATE,map_get_prevision_state);
+    CL_Lua::record(C_MAP_SET_PREVISION_STATE,map_set_prevision_state);
+    CL_Lua::record(C_MAP_GET_PREVIEW_STATE,map_get_preview_state);
+    CL_Lua::record(C_MAP_SET_PREVIEW_STATE,map_set_preview_state);
 }
 
 
