@@ -73,7 +73,8 @@ public:
     static void block_move_right(U61_Block *b);
     static void block_move_down(U61_Block *b);
     static void block_land(U61_Map *m,U61_Block *b);
-    static void map_match_pattern(U61_Map *m);
+    static bool map_match_pattern(U61_Map *m);
+    static void map_time_callback(U61_Map *m,U61_Block *b);
 
     static char *const LUA_BLOCK_SHAPE="user_block_shape";
     static char *const LUA_BLOCK_ROTATE_LEFT="user_block_rotate_left";
@@ -83,6 +84,7 @@ public:
     static char *const LUA_BLOCK_MOVE_DOWN="user_block_move_down";
     static char *const LUA_BLOCK_LAND="user_block_land";
     static char *const LUA_MAP_MATCH_PATTERN="user_map_match_pattern";
+    static char *const LUA_MAP_TIME_CALLBACK="user_map_time_callback";
 
     static char *const C_BLOCK_RESET="u61_block_reset";
     static char *const C_BLOCK_CENTER="u61_block_center";
@@ -102,8 +104,17 @@ public:
     static char *const C_MAP_GET_HEIGHT="u61_map_get_height";
     static char *const C_MAP_GET_SQUARE_COLOR="u61_map_get_square_color";
     static char *const C_MAP_SET_SQUARE_COLOR="u61_map_set_square_color";
+    static char *const C_MAP_GET_TIME="u61_map_get_time";
+    static char *const C_MAP_GET_NB_GAMES="u61_map_get_nb_games";
     static char *const C_MAP_GET_SCORE="u61_map_get_score";
     static char *const C_MAP_SET_SCORE="u61_map_set_score";
+    static char *const C_MAP_ADD_SCORE="u61_map_add_score";
+    static char *const C_MAP_GET_GLOBAL="u61_map_get_global";
+    static char *const C_MAP_SET_GLOBAL="u61_map_set_global";
+    static char *const C_MAP_GET_PREVISION_STATE="u61_map_get_prevision_state";
+    static char *const C_MAP_SET_PREVISION_STATE="u61_map_set_prevision_state";
+    static char *const C_MAP_GET_PREVIEW_STATE="u61_map_get_preview_state";
+    static char *const C_MAP_SET_PREVIEW_STATE="u61_map_set_preview_state";
 
 protected:
     static void secure_pointers();
